@@ -23,15 +23,14 @@ import glob
 import io
 import json
 import os
+import pkg_resources
 import re
 import subprocess
 import sys
 import toml
 import argparse
 
-from dcicutils.env_utils import (
-    is_stg_or_prd_env, prod_bucket_env, get_standard_mirror_env, data_set_for_env, INDEXER_ENVS
-)
+from dcicutils.env_utils import get_standard_mirror_env, data_set_for_env, get_bucket_env, INDEXER_ENVS
 from dcicutils.misc_utils import PRINT
 
 
@@ -101,8 +100,13 @@ class Deployer:
         except Exception:
             return 'unknown-version-at-' + datetime.datetime.now().strftime("%Y%m%d%H%M%S%f")
 
+    PARAMETERIZED_ASSIGNMENT = re.compile(r'^[ \t]*[A-Za-z][A-Za-z0-9.-_]*[ \t]*=[ \t]*[$][{]?[A-Za-z].*$')
     EMPTY_ASSIGNMENT = re.compile(r'^[ \t]*[A-Za-z][A-Za-z0-9.-_]*[ \t]*=[ \t\r\n]*$')
 
+    @classmethod
+    def omittable(cls, line, expanded_line):
+        return cls.PARAMETERIZED_ASSIGNMENT.match(line) and cls.EMPTY_ASSIGNMENT.match(expanded_line)
+
     @classmethod
     def build_ini_stream_from_template(cls, template_file_name, init_file_stream,
                                        bs_env=None, bs_mirror_env=None, s3_bucket_env=None, data_set=None,
@@ -130,10 +134,7 @@ class Deployer:
         es_server = es_server or os.environ.get('ENCODED_ES_SERVER', "MISSING_ENCODED_ES_SERVER")
         bs_env = bs_env or os.environ.get("ENCODED_BS_ENV", "MISSING_ENCODED_BS_ENV")
         bs_mirror_env = bs_mirror_env or os.environ.get("ENCODED_BS_MIRROR_ENV", get_standard_mirror_env(bs_env)) or ""
-        s3_bucket_env = s3_bucket_env or os.environ.get("ENCODED_S3_BUCKET_ENV",
-                                                        prod_bucket_env(bs_env)
-                                                        if is_stg_or_prd_env(bs_env)
-                                                        else bs_env)
+        s3_bucket_env = s3_bucket_env or os.environ.get("ENCODED_S3_BUCKET_ENV", get_bucket_env(bs_env))
         data_set = data_set or os.environ.get("ENCODED_DATA_SET",
                                               data_set_for_env(bs_env) or "MISSING_ENCODED_DATA_SET")
         es_namespace = es_namespace or os.environ.get("ENCODED_ES_NAMESPACE", bs_env)
@@ -148,6 +149,8 @@ class Deployer:
         extra_vars = {
             'APP_VERSION': cls.get_app_version(),
             'PROJECT_VERSION': toml.load(cls.PYPROJECT_FILE_NAME)['tool']['poetry']['version'],
+            'SNOVAULT_VERSION': pkg_resources.get_distribution("dcicsnovault").version,
+            'UTILS_VERSION': pkg_resources.get_distribution("dcicutils").version,
             'ES_SERVER': es_server,
             'BS_ENV': bs_env,
             'BS_MIRROR_ENV': bs_mirror_env,
@@ -183,7 +186,7 @@ class Deployer:
                     # if '$' in line:
                     #     print("line=", line)
                     #     print("expanded_line=", expanded_line)
-                    if not cls.EMPTY_ASSIGNMENT.match(expanded_line):
+                    if not cls.omittable(line, expanded_line):
                         init_file_stream.write(expanded_line)
 
         finally:
@@ -193,6 +196,13 @@ class Deployer:
                 # Most things probably don't care, but testing might.
                 del os.environ[key]
 
+    @classmethod
+    def any_environment_template_filename(cls):
+        file = os.path.join(cls.TEMPLATE_DIR, "any.ini")
+        if not os.path.exists(file):
+            raise ValueError("Special template any.ini was not found.")
+        return file
+
     @classmethod
     def environment_template_filename(cls, env_name):
         prefixes = ["fourfront-", "cgap-"]
@@ -227,6 +237,13 @@ class Deployer:
                 description="Generates a product.ini file from a template appropriate for the given environment,"
                             " which defaults from the value of the ENV_NAME environment variable "
                             " and may be given with or without a 'fourfront-' prefix. ")
+            parser.add_argument("--use_any",
+                                help="whether or not to prefer the new any.ini template over a named template",
+                                action='store_true',
+                                # In order for us to change the default to True, we'd need to re-issue beanstalks
+                                # with the new environment variables. The any.ini template relies on different
+                                # variables. -kmp 29-Apr-2020
+                                default=False)
             parser.add_argument("--env",
                                 help="environment name",
                                 default=os.environ['ENV_NAME'],
@@ -258,7 +275,9 @@ class Deployer:
                                 action='store_true',
                                 default=False)
             args = parser.parse_args()
-            template_file_name = cls.environment_template_filename(args.env)
+            template_file_name = (cls.any_environment_template_filename()
+                                  if args.use_any
+                                  else cls.environment_template_filename(args.env))
             ini_file_name = args.target
             # print("template_file_name=", template_file_name)
             # print("ini_file_name=", ini_file_name)
